==> zio-aws-elasticbeanstalk_3-5.17.129.2-sources.jar: zio/aws/elasticbeanstalk/model/CreateApplicationResponse.scala <==
package zio.aws.elasticbeanstalk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateApplicationResponse(
    application: Option[zio.aws.elasticbeanstalk.model.ApplicationDescription] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse = {
    import CreateApplicationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse
      .builder()
      .optionallyWith(application.map(value => value.buildAwsValue()))(
        _.application
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticbeanstalk.model.CreateApplicationResponse.ReadOnly =
    zio.aws.elasticbeanstalk.model.CreateApplicationResponse
      .wrap(buildAwsValue())
}
object CreateApplicationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticbeanstalk.model.CreateApplicationResponse =
      zio.aws.elasticbeanstalk.model
        .CreateApplicationResponse(application.map(value => value.asEditable))
    def application
        : Option[zio.aws.elasticbeanstalk.model.ApplicationDescription.ReadOnly]
    def getApplication: ZIO[
      Any,
      AwsError,
      zio.aws.elasticbeanstalk.model.ApplicationDescription.ReadOnly
    ] = AwsError.unwrapOptionField("application", application)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse
  ) extends zio.aws.elasticbeanstalk.model.CreateApplicationResponse.ReadOnly {
    override val application: Option[
      zio.aws.elasticbeanstalk.model.ApplicationDescription.ReadOnly
    ] = scala
      .Option(impl.application())
      .map(value =>
        zio.aws.elasticbeanstalk.model.ApplicationDescription.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse
  ): zio.aws.elasticbeanstalk.model.CreateApplicationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticbeanstalk_3-5.17.195.1-sources.jar: zio/aws/elasticbeanstalk/model/CreateApplicationResponse.scala <==
package zio.aws.elasticbeanstalk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateApplicationResponse(
    application: Optional[
      zio.aws.elasticbeanstalk.model.ApplicationDescription
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse = {
    import CreateApplicationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse
      .builder()
      .optionallyWith(application.map(value => value.buildAwsValue()))(
        _.application
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticbeanstalk.model.CreateApplicationResponse.ReadOnly =
    zio.aws.elasticbeanstalk.model.CreateApplicationResponse
      .wrap(buildAwsValue())
}
object CreateApplicationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticbeanstalk.model.CreateApplicationResponse =
      zio.aws.elasticbeanstalk.model
        .CreateApplicationResponse(application.map(value => value.asEditable))
    def application: Optional[
      zio.aws.elasticbeanstalk.model.ApplicationDescription.ReadOnly
    ]
    def getApplication: ZIO[
      Any,
      AwsError,
      zio.aws.elasticbeanstalk.model.ApplicationDescription.ReadOnly
    ] = AwsError.unwrapOptionField("application", application)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse
  ) extends zio.aws.elasticbeanstalk.model.CreateApplicationResponse.ReadOnly {
    override val application: Optional[
      zio.aws.elasticbeanstalk.model.ApplicationDescription.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.application())
      .map(value =>
        zio.aws.elasticbeanstalk.model.ApplicationDescription.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.CreateApplicationResponse
  ): zio.aws.elasticbeanstalk.model.CreateApplicationResponse.ReadOnly =
    new Wrapper(impl)
}
